@@ -12,17 +12,19 @@ import logging
 import os
 
 from fastapi import FastAPI
+from fastapi.middleware.cors import CORSMiddleware
 
 from rcsb.utils.chem.ChemCompDepictWrapper import ChemCompDepictWrapper
 from rcsb.utils.chem.ChemCompSearchWrapper import ChemCompSearchWrapper
 
-
+from . import convertTools
 from . import depictTools
 from . import descriptorMatch
 from . import formulaMatch
 from . import LogFilterUtils
 from . import serverStatus
 
+#
 # ---
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -41,6 +43,16 @@ lu.addFilters()
 
 app = FastAPI()
 
+app.add_middleware(
+    CORSMiddleware,
+    allow_origins=["*"],
+    # allow_origin_regex="https?://.*",
+    allow_credentials=True,
+    allow_methods=["*"],
+    allow_headers=["*"],
+)
+# http --verbose OPTIONS :8000/status  Access-Control-Request-Method:GET Origin:https://id-localtest.mydomain.co
+
 
 @app.on_event("startup")
 async def startupEvent():
@@ -59,8 +71,9 @@ async def startupEvent():
     ok1 = ccsw.readConfig()
     ok2 = ccsw.updateChemCompIndex(useCache=True)
     ok3 = ccsw.reloadSearchDatabase()
+    ok4 = ccsw.updateSearchIndex(useCache=True)
     #
-    logger.info("Completed - loading search dependencies status %r", ok1 and ok2 and ok3)
+    logger.info("Completed - loading search dependencies status %r", ok1 and ok2 and ok3 and ok4)
     ccdw = ChemCompDepictWrapper()
     ok1 = ccdw.readConfig()
     logger.info("Completed - loading depict dependencies status %r", ok1)
@@ -89,4 +102,9 @@ app.include_router(
     prefix="/chem-depict-v1",
 )
 
+app.include_router(
+    convertTools.router,
+    prefix="/chem-convert-v1",
+)
+
 app.include_router(serverStatus.router)
